@@ -1,4 +1,4 @@
 {
     # No Logger while testing
-    modules_disable => ['Logger']
+    "-modules" => ['Logger']
 };
